/**
 * This file is part of the swagger-jsdoc-express distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * swagger-jsdoc-express is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * swagger-jsdoc-express is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
import * as doctrine from 'doctrine';
/**
 * Additional and custom options for 'parseSwaggerV2DocBlocks()' function.
 */
export interface ParseSwaggerV2DocBlocksOptions {
    /**
     * Show debug message(s), like errors or not.
     */
    'debug'?: boolean;
}
/**
 * A general Swagger V2 documentation block.
 */
export interface SwaggerV2DocBlock<TDetails extends object = object> {
    /**
     * The summary.
     */
    'description'?: string;
    /**
     * The details.
     */
    'details': TDetails | false | null | undefined;
    /**
     * The underlying JSDoc annotation.
     */
    'jsDoc': doctrine.Annotation;
    /**
     * The type.
     */
    'type': string;
}
/**
 * A Swagger V2 documentation block for a definition.
 */
export interface SwaggerV2DefinitionDocBlock extends SwaggerV2DocBlock {
    /** @inheritdoc */
    'type': 'definition';
}
/**
 * A Swagger V2 documentation block for a path.
 */
export interface SwaggerV2PathDocBlock extends SwaggerV2DocBlock {
    /** @inheritdoc */
    'type': 'path';
}
/**
 * Extracts / parses Swagger V2 documentation inside JSDoc blocks.
 *
 * @param {string} code The source code with the JSDoc blocks.
 * @param {ParseSwaggerV2DocBlocksOptions} [opts] Additional and custom options.
 *
 * @return {SwaggerV2DocBlock[]} The list of documentation.
 */
export declare function parseSwaggerV2DocBlocks(code: string, opts?: ParseSwaggerV2DocBlocksOptions): SwaggerV2DocBlock[];
